@@ -1,11 +1,11 @@
 use strict;
 use warnings;
-package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.022-2-gaa9083e
+package Dist::Zilla::Plugin::Git::Contributors; # git description: v0.023-7-gfcd9374
 # ABSTRACT: Add contributor names from git to your distribution
 # KEYWORDS: plugin distribution metadata git contributors authors commits
 # vim: set ts=8 sts=4 sw=4 tw=115 et :
 
-our $VERSION = '0.023';
+our $VERSION = '0.024';
 
 use Moose;
 with 'Dist::Zilla::Role::MetaProvider',
@@ -71,6 +71,7 @@ around dump_config => sub
                      ($dist_root->subsumes($p) ? $p->relative($dist_root) : $p)->stringify
                    } $self->paths ],
         $self->remove ? ( remove => '...' ) : (),
+        'git --version' => $self->_git('version'),
         blessed($self) ne __PACKAGE__ ? ( version => $VERSION ) : (),
     };
 
@@ -115,10 +116,10 @@ sub register_prereqs
     return if any { /^Dist::Zilla/ } keys %$all_prereqs;
 
     # if dynamic_config is set, the user gets another chance to read the file, via fallback code:
-    # 22:44 < haarg> eumm loads META, updates prereqs, and writes out MYMETA
-    # 22:44 < haarg> so in a working system, x_contributors will be included
-    # 22:45 < haarg> in a broken system, it will fail to load META, regenerate it from parameters including META_ADD/MERGE, then write it out
-    # 22:46 < haarg> so if there isn't any utf8 data in the parameters given to EUMM, it will produce a file that can be read by a "bad" JSON::PP
+    # < haarg> eumm loads META, updates prereqs, and writes out MYMETA
+    # < haarg> so in a working system, x_contributors will be included
+    # < haarg> in a broken system, it will fail to load META, regenerate it from parameters including META_ADD/MERGE, then write it out
+    # < haarg> so if there isn't any utf8 data in the parameters given to EUMM, it will produce a file that can be read by a "bad" JSON::PP
     return if $self->zilla->distmeta->{dynamic_config};
 
     # see https://github.com/makamaka/JSON-PP/pull/9 for for details
@@ -146,6 +147,7 @@ sub _build_contributors
 
     my $in_repo;
     try {
+        # note that ->status does something different.
         $in_repo = $self->_git(RUN => 'status');
     }
     catch {
@@ -239,6 +241,7 @@ sub _git
 {
     my ($self, $command, @args) = @_;
 
+    die 'no command?!' if not $command;
     my $git = $self->__git;
     my @result = $git->$command(@args);
     my $err = $git->ERR;
@@ -263,7 +266,7 @@ Dist::Zilla::Plugin::Git::Contributors - Add contributor names from git to your
 
 =head1 VERSION
 
-version 0.023
+version 0.024
 
 =head1 SYNOPSIS
 
